@@ -193,6 +193,10 @@ create_bootinfo
     if (!add_bi_string(BI_COMMAND_LINE, bi.command_line))
 		return FALSE;
 
+    /* add VME specific bootinfo fields */
+    if (!add_vme_bootinfo())
+        return FALSE;
+
     /* Trailer */
     record      = (struct bi_record *)
 						((unsigned long)&bi_union.record + bi_size);
@@ -443,7 +447,7 @@ load_kernel
 	{
 		if (debug_mode)
 		{
-			printf("Kernel segment %u at 0x%08lx, size %lu, align %lu\n",
+			printf("Kernel segment %u at 0x%08lx, size %u, align %u\n",
 				i,
 				mem_start + kernel_phdrs[i].p_vaddr - PAGE_SIZE,
 				kernel_phdrs[i].p_memsz,
@@ -467,7 +471,7 @@ load_kernel
 
  	if (debug_mode)
 	{
-		printf("Kernel entry is 0x%08lx.\n", kexec_elf.e_entry);
+		printf("Kernel entry is 0x%08x.\n", kexec_elf.e_entry);
 	}
 
 	sclose();
@@ -510,7 +514,6 @@ boot_linux
 	char				*kernel_load_addr  = NULL;
 	char				*ramdisk_load_addr = NULL;
     void				*bi_ptr;
-	const char			*p;
 
     mem_clear(&bi, sizeof(bi));
 
@@ -518,7 +521,7 @@ boot_linux
 	bi.machtype = get_machtype();
 
 	/* detect and configure cpu/fpu type */
-	switch (i = cpu_type())
+	switch (cpu_type)
 	{
 		case 40:
 		{
@@ -533,7 +536,7 @@ boot_linux
 		}
 	}
 	bi.mmutype = bi.cputype;
-	if (fpu_type())
+	if (fpu_type)
 		bi.fputype = bi.cputype;
 	else
 		bi.fputype = 0;
@@ -541,9 +544,9 @@ boot_linux
 	if (debug_mode)
 	{
 		put_char('\n');
-		print_model(i, bi.fputype);
+		print_model();
 		printf(" CPU:680%u with%s FPU\n",
-			i, bi.fputype ? " internal" : "out");
+			cpu_type, fpu_type ? " internal" : "out");
 	}
 
 	/* if no ram size has been specified */
@@ -595,33 +598,6 @@ boot_linux
 		}
 	}
 
-	/* get command line */
-	strncpy(bi.command_line, "BOOT_IMAGE=", CL_SIZE);
-	strncat(bi.command_line, boot->label,   CL_SIZE);
-	if (autoboot)
-	{
-		strncat(bi.command_line, " auto", CL_SIZE);
-	}
-
-	/* override boot command line with user specified input */
-	if ((p = more[0] ? more : boot->cmdline) != NULL)
-	{
-		strncat(bi.command_line, " ", CL_SIZE);
-   		substip(bi.command_line, p,   CL_SIZE);
-   	}
-
-   	/* any parameters to append */
-	if (boot->append)
-   	{
-		strncat(bi.command_line, " ",          CL_SIZE);
-   		substip(bi.command_line, boot->append, CL_SIZE);
-   	}
-
-   	if (debug_mode)
-   	{
-		printf("Using command line `%s'.\n", bi.command_line);
-	}
-
 	mem_start = bi.memory[0].addr;
 	mem_size  = bi.memory[0].size;
 	mem_end   = mem_start + mem_size;
@@ -673,6 +649,65 @@ boot_linux
     /* Check kernel's bootinfo version */
     kernel_major = check_bootinfo_version(kernel_load_addr);
 
+	/* build kernel command line
+	 */
+
+	/* environment variable indicating loaded boot record */
+	strncpy(bi.command_line, "BOOT_IMAGE=", CL_SIZE);
+	strcatn(bi.command_line, boot->label,   CL_SIZE);
+
+	/* add 'auto' flag if we didn't ask for input */
+	if (autoboot)
+	{
+		strcatn(bi.command_line, " auto", CL_SIZE);
+	}
+
+	/* append root device */
+	if (boot->root)
+	{
+		strcatn(bi.command_line, " root=",   CL_SIZE);
+   		strcatn(bi.command_line, boot->root, CL_SIZE);
+	}
+
+	/* append boot record read-only/read-write flag */
+	if (boot->read_only == TRUE || boot->read_only == FALSE)
+	{
+   		strcatn(bi.command_line, boot->read_only ? " ro" : " rw", CL_SIZE);
+	}
+
+	/* append boot record console device, for kernels later than 2.0.xx */
+	if (boot->console && (kernel_major > 1))
+	{
+		strcatn(bi.command_line, " console=",   CL_SIZE);
+   		strcatn(bi.command_line, boot->console, CL_SIZE);
+	}
+
+   	/* boot record command line */
+	if (boot->cmdline)
+   	{
+		strcatn(bi.command_line, " ",           CL_SIZE);
+   		substip(bi.command_line, boot->cmdline, CL_SIZE);
+   	}
+
+	/* append user specified input */
+	if (more[0])
+	{
+		strcatn(bi.command_line, " ",  CL_SIZE);
+   		substip(bi.command_line, more, CL_SIZE);
+   	}
+
+   	/* any additional parameters to append */
+	if (boot->append)
+   	{
+		strcatn(bi.command_line, " ",          CL_SIZE);
+   		substip(bi.command_line, boot->append, CL_SIZE);
+   	}
+
+   	if (debug_mode)
+   	{
+		printf("Using command line `%s'.\n", bi.command_line);
+	}
+
    	if (kernel_major == BI_VERSION_MAJOR(get_booti_version()))
 	{
 	    /* create the bootinfo structure */
@@ -722,9 +757,12 @@ boot_linux
 
 		printf("Boot info at 0x%08lx.\n", mem_start + kernel_size);
 
-		put_str("\nPress a key to continue booting... ");
-		get_char(NO_TIMEOUT);
-		put_char('\n');
+		if (!boot->calldbg)
+		{
+			put_str("\nPress a key to continue booting... ");
+			get_char(NO_TIMEOUT);
+			put_char('\n');
+		}
 	}
 
 	/* move the copy-and-go code to it's proper place */
