@@ -35,6 +35,12 @@ enum keyword_id {
 	KW_DEFAULT,
 	KW_IP,
 	KW_DEBUG,
+	KW_ROOT,
+	KW_CONSOLE,
+	KW_READ_ONLY,
+	KW_READ_WRITE,
+	KW_DESCRIPTION,
+	KW_DISPLAY
 };
 
 static struct keyword {
@@ -58,7 +64,13 @@ static struct keyword {
 	{"boot",		KW_BOOT			},
 	{"default",		KW_DEFAULT		},
 	{"ip",			KW_IP			},
-	{"debug",		KW_DEBUG		}
+	{"debug",		KW_DEBUG		},
+	{"root",		KW_ROOT			},
+	{"console",		KW_CONSOLE		},
+	{"read-only",	KW_READ_ONLY	},
+	{"read-write",	KW_READ_WRITE	},
+	{"description",	KW_DESCRIPTION	},
+	{"display",		KW_DISPLAY		}
 };
 
 #define NUMKEYWORDS	(sizeof(keywords) / sizeof(keywords[0]))
@@ -102,6 +114,52 @@ goto_line
 	return p;
 }
 
+/*--------------------------------------------------------------------------*/
+/* Find start of spacified [display] section.
+ * Returns line number of line following section marker or zero if not found.
+ */
+
+int
+find_display_section
+(	const char	*label
+)
+{	char		name[32];
+	char		buff[sizeof(name)];
+	int			line	   = 1;
+	char		*cfgp	   = config_data;
+	char		*p;
+
+	strcpy(buff, "display");
+	if (label && *label)
+	{
+		strcat(buff, "-");
+		strcatn(buff, label, sizeof(buff));
+	}
+	label = buff;
+
+	while (cfgp != config_data_end)
+	{
+		if (*cfgp == '[')
+		{
+			/* get section name */
+			p = extract(name, cfgp + 1, sizeof(name), ']');
+
+			/* is this the section */
+			if (equal_strings(name, label) && check_arch(p))
+			{
+				return line + 1;
+			}
+		}
+
+		/* next line */
+		line++;
+		cfgp += (strlen(cfgp) + 1);
+	}
+
+	/* not found */
+	return 0;
+}
+
 /*--------------------------------------------------------------------------*/
 /* Find start of [boot] section with specified label name.
  * Returns line number of first option in section or zero if not found.
@@ -123,10 +181,10 @@ find_boot_section
 		if (*cfgp == '[')
 		{
 			/* get section name */
-			extract(name, cfgp + 1, sizeof(name), ']');
+			p = extract(name, cfgp + 1, sizeof(name), ']');
 
 			/* is this the section */
-			if (equal_strings(name, "boot"))
+			if (equal_strings(name, "boot") && check_arch(p))
 			{
 				in_section = TRUE;
 				where	   = line;
@@ -186,10 +244,10 @@ find_crate_section
 		if (*cfgp == '[')
 		{
 			/* get section name */
-			extract(name, cfgp + 1, sizeof(name), ']');
+			p = extract(name, cfgp + 1, sizeof(name), ']');
 
 			/* is this a [crate] section */
-			if (equal_strings(name, "crate"))
+			if (equal_strings(name, "crate") && check_arch(p))
 			{
 				in_section = TRUE;
 				where	   = line;
@@ -250,10 +308,10 @@ find_default_crate_section
 			}
 
 			/* get section name */
-			extract(name, cfgp + 1, sizeof(name), ']');
+			p = extract(name, cfgp + 1, sizeof(name), ']');
 
 			/* is this a [crate] section */
-			if (equal_strings(name, "crate"))
+			if (equal_strings(name, "crate") && check_arch(p))
 			{
 				in_section = TRUE;
 				where	   = line + 1;
@@ -406,6 +464,11 @@ get_bool
 )
 {	unsigned long	result;
 
+	if (text[0] == '\0')
+	{
+		return TRUE;
+	}
+
 	if (equal_strings(text, "true")
 	||	equal_strings(text, "yes" ))
 	{
@@ -560,8 +623,14 @@ dump_crate
 		printf("label         = %s\n", boot->label);
 		if (boot->alias)
 			printf("alias         = %s\n", boot->alias);
+		if (boot->description)
+			printf("description   = %s\n", boot->description);
 		printf("kernel        = %s\n", boot->kernel);
 		printf("ramdisk       = %s\n", boot->ramdisk ? boot->ramdisk : "None");
+		printf("console       = %s\n", boot->console ? boot->console : "");
+		printf("root          = %s\n", boot->root    ? boot->root    : "");
+		if      (boot->read_only == TRUE ) printf("read-only\n");
+		else if (boot->read_only == FALSE) printf("read-write\n");
 		printf("cmdline       = %s\n", boot->cmdline ? boot->cmdline : "");
 		printf("append        = %s\n", boot->append  ? boot->append  : "");
 		printf("restricted    = %s\n", boot->restricted ? "Yes" : "No");
@@ -597,16 +666,20 @@ parse_boot
 	BOOT			*boot	 = xmalloc(sizeof(BOOT));
 
 	/* setup defaults */
-	boot->restricted = crate->restricted;
-	boot->calldbg	 = crate->calldbg;
-	boot->memsize	 = crate->memsize;
-	boot->cmdline	 = crate->cmdline;
-	boot->append	 = crate->append;
-	boot->kernel	 = crate->kernel;
-	boot->ramdisk	 = crate->ramdisk;
-	boot->alias		 = NULL;
-	boot->label		 = NULL;
-	boot->next		 = NULL;
+	boot->restricted  = crate->restricted;
+	boot->calldbg	  = crate->calldbg;
+	boot->memsize	  = crate->memsize;
+	boot->cmdline	  = crate->cmdline;
+	boot->append	  = crate->append;
+	boot->kernel	  = crate->kernel;
+	boot->ramdisk	  = crate->ramdisk;
+	boot->root        = crate->root;
+	boot->console     = crate->console;
+	boot->read_only   = crate->read_only;
+	boot->description = NULL;
+	boot->alias		  = NULL;
+	boot->label		  = NULL;
+	boot->next		  = NULL;
 
 	/* seek to specified line number */
 	cfgp = goto_line(line);
@@ -640,6 +713,10 @@ parse_boot
 					boot->alias = despace(p);
 					break;
 
+				case KW_DESCRIPTION:
+					boot->description = p;
+					break;
+
 				case KW_CMDLINE:
 					boot->cmdline = p;
 					break;
@@ -676,6 +753,28 @@ parse_boot
 					boot->memsize = PAGE_BOUNDARY(number);
 					break;
 
+				case KW_ROOT:
+					boot->root = p;
+					break;
+
+				case KW_CONSOLE:
+					if (mem_cmp(p, "/dev/", 5) == 0)
+						p += 5;
+					boot->console = p;
+					break;
+
+				case KW_READ_ONLY:
+					if ((bool = get_bool(p)) == FAILURE)
+						bool = bool_config_error(line, cfgp, boot->read_only != FALSE);
+					boot->read_only = bool;
+					break;
+
+				case KW_READ_WRITE:
+					if ((bool = get_bool(p)) == FAILURE)
+						bool = bool_config_error(line, cfgp, boot->read_only == FALSE);
+					boot->read_only = !bool;
+					break;
+
 				default:
 					ignore_option(line, cfgp);
 					break;
@@ -729,7 +828,7 @@ void
 build_boot_from_defaults
 (	CRATE		*crate
 )
-{	BOOT			*boot;
+{	BOOT		*boot;
 
 	/* if no default kernel */
 	if (crate->kernel == NULL)
@@ -741,16 +840,20 @@ build_boot_from_defaults
 	boot = xmalloc(sizeof(BOOT));
 
 	/* setup defaults */
-	boot->restricted = crate->restricted;
-	boot->calldbg	 = crate->calldbg;
-	boot->memsize	 = crate->memsize;
-	boot->cmdline	 = crate->cmdline;
-	boot->append	 = crate->append;
-	boot->kernel	 = crate->kernel;
-	boot->ramdisk	 = crate->ramdisk;
-	boot->alias		 = NULL;
-	boot->label		 = "linux";
-	boot->next		 = NULL;
+	boot->restricted  = crate->restricted;
+	boot->calldbg	  = crate->calldbg;
+	boot->memsize	  = crate->memsize;
+	boot->cmdline	  = crate->cmdline;
+	boot->append	  = crate->append;
+	boot->kernel	  = crate->kernel;
+	boot->ramdisk	  = crate->ramdisk;
+	boot->root        = crate->root;
+	boot->console     = crate->console;
+	boot->read_only   = crate->read_only;
+	boot->description = NULL;
+	boot->alias		  = NULL;
+	boot->label		  = "linux";
+	boot->next		  = NULL;
 
 	add_boot(crate, boot);
 }
@@ -766,6 +869,7 @@ build_boot_list
 {	char			*cfgp	  = config_data;
 	int				line	  = 1;
 	char			name[32];
+	char			*p;
 
 	/* until end of data */
 	while (cfgp != config_data_end)
@@ -774,9 +878,9 @@ build_boot_list
 		if (*cfgp == '[')
 		{
 			/* get section name */
-			extract(name, cfgp + 1, sizeof(name), ']');
+			p = extract(name, cfgp + 1, sizeof(name), ']');
 
-			if (equal_strings(name, "boot"))
+			if (equal_strings(name, "boot") && check_arch(p))
 			{
 				/* add it */
 				add_boot(crate, parse_boot(line + 1, crate));
@@ -807,10 +911,14 @@ parse_globals
 	crate->timeout	  = 0;
 	crate->delay	  = 3;
 	crate->prompt	  = FALSE;
+	crate->display    = NULL;
 	crate->cmdline	  = NULL;
 	crate->append	  = NULL;
 	crate->kernel     = NULL;
 	crate->ramdisk    = NULL;
+	crate->root       = NULL;
+	crate->console    = "ttyS0";
+	crate->read_only  = -1;		/* undefined */
 	crate->restricted = FALSE;
 	crate->calldbg	  = FALSE;
 	crate->memsize	  = 0;		/* auto detect */
@@ -870,6 +978,12 @@ parse_globals
 					crate->memsize = PAGE_BOUNDARY(number);
 					break;
 
+				case KW_DISPLAY:
+					if (crate->display)
+						goto duplicate;
+					crate->display = p;
+					break;
+
 				case KW_KERNEL:
 					if (crate->kernel)
 						goto duplicate;
@@ -893,6 +1007,30 @@ parse_globals
 					crate->append = p;
 					break;
 
+				case KW_ROOT:
+					if (crate->root)
+						goto duplicate;
+					crate->root = p;
+					break;
+
+				case KW_CONSOLE:
+					if (mem_cmp(p, "/dev/", 5) == 0)
+						p += 5;
+					crate->console = p;
+					break;
+
+				case KW_READ_ONLY:
+					if ((bool = get_bool(p)) == FAILURE)
+						bool = bool_config_error(line, cfgp, crate->read_only != FALSE);
+					crate->read_only = bool;
+					break;
+
+				case KW_READ_WRITE:
+					if ((bool = get_bool(p)) == FAILURE)
+						bool = bool_config_error(line, cfgp, crate->read_only == FALSE);
+					crate->read_only = !bool;
+					break;
+
 				default:
 					ignore_option(line, cfgp);
 					break;
@@ -994,6 +1132,10 @@ parse_config
 					crate->prompt = bool;
 					break;
 
+				case KW_DISPLAY:
+					crate->display = p;
+					break;
+
 				case KW_KERNEL:
 					crate->kernel = p;
 					break;
@@ -1030,6 +1172,28 @@ parse_config
 					crate->memsize = PAGE_BOUNDARY(number);
 					break;
 
+				case KW_ROOT:
+					crate->root = p;
+					break;
+
+				case KW_CONSOLE:
+					if (mem_cmp(p, "/dev/", 5) == 0)
+						p += 5;
+					crate->console = p;
+					break;
+
+				case KW_READ_ONLY:
+					if ((bool = get_bool(p)) == FAILURE)
+						bool = bool_config_error(line, cfgp, crate->read_only != FALSE);
+					crate->read_only = bool;
+					break;
+
+				case KW_READ_WRITE:
+					if ((bool = get_bool(p)) == FAILURE)
+						bool = bool_config_error(line, cfgp, crate->read_only == FALSE);
+					crate->read_only = !bool;
+					break;
+
 				case KW_BOOT:
 				case KW_DEFAULT:
 					/* handle these in second pass
@@ -1143,4 +1307,39 @@ parse_config
 		dump_crate(crate);
 }
 
+/*--------------------------------------------------------------------------*/
+/* Dump contents of [display] section to console
+ * Returns TRUE if message printed or no message required
+ */
+
+int
+print_display_section
+(	const char	*label
+)
+{	char		*cfgp;
+	int			line;
+
+	if ((line = find_display_section(label)) == 0)
+	{
+		return label ? FALSE : TRUE;
+	}
+
+	cfgp = goto_line(line);
+
+	/* until end of data or start of next section */
+	while (cfgp != config_data_end && *cfgp != '[')
+	{
+		/* ignore blank lines */
+		if (*cfgp != '\0')
+		{
+			put_estr(cfgp);
+		}
+
+		/* next line */
+		cfgp += (strlen(cfgp) + 1);
+	}
+
+	return TRUE;
+}
+
 /*-----------------------------< end of file >------------------------------*/
