@@ -18,11 +18,11 @@
 __asm__(".text\n"
 __ALIGN_STR "\n"
 ".globl " SYMBOL_NAME_STR(_start) ";\n"
-SYMBOL_NAME_STR(_start) ":
-
-	movem.l	%d0-%d7/%a0-%a6,-(%sp)
-	move.l	%sp,-(%sp)
-	jsr	(" SYMBOL_NAME_STR(Main) ");
+SYMBOL_NAME_STR(_start) ":				\n\
+										\n\
+	movem.l	%d0-%d7/%a0-%a6,-(%sp)		\n\
+	move.l	%sp,-(%sp)					\n\
+	jsr	(" SYMBOL_NAME_STR(Main) ");	\n\
 ");
 
 /*-----------------------------< end of file >------------------------------*/
