@@ -134,13 +134,12 @@ MVMEBug_putchar
 {	register unsigned long	d0 asm("d0") = (unsigned long) c;
 
 	asm volatile (
-		"	move.b	%%d0,-(%%sp)
-			trap	#15
-			dc.w	0x0020
+		"	move.b	%%d0,-(%%sp)	\n\
+			trap	#15				\n\
+			dc.w	0x0020			\n\
 		"
 		: /* no outputs */
 		: "r" (d0)
-		: "d0"
 	);
 }
 
@@ -159,14 +158,13 @@ MVMEBug_putstr
 	register void			*a1 asm("a1") = (void *) end;
 
 	asm volatile (
-		"	move.l	%%a1,-(%%sp)
-			move.l	%%a0,-(%%sp)
-			trap	#15
-			dc.w	0x0021
+		"	move.l	%%a1,-(%%sp)	\n\
+			move.l	%%a0,-(%%sp)	\n\
+			trap	#15				\n\
+			dc.w	0x0021			\n\
 		"
 		: /* no outputs */
 		: "r" (a0), "r" (a1)
-		: "a0", "a1"
 	);
 }
 
@@ -185,14 +183,13 @@ MVMEBug_print
 	register void			*a1 asm("a1") = (void *) vap;
 
 	asm volatile (
-		"	move.l	%%a1,-(%%sp)
-			move.l	%%a0,-(%%sp)
-			trap	#15
-			dc.w	0x0028
+		"	move.l	%%a1,-(%%sp)	\n\
+			move.l	%%a0,-(%%sp)	\n\
+			trap	#15				\n\
+			dc.w	0x0028			\n\
 		"
 		: /* no outputs */
 		: "r" (a0), "r" (a1)
-		: "a0", "a1"
 	);
 }
 
@@ -209,14 +206,13 @@ MVMEBug_getchar
 {	register unsigned long	d0 asm("d0") = 0;
 
 	asm volatile (
-		"	subq.l	#2,%%sp
-			trap	#15
-			dc.w	0x0000
-			move.b	(%%sp)+,%%d0
+		"	subq.l	#2,%%sp			\n\
+			trap	#15				\n\
+			dc.w	0x0000			\n\
+			move.b	(%%sp)+,%%d0	\n\
 		"
 		: "=r" (d0)
 		: "r" (d0)
-		: "d0"
 	);
 
 	return d0;
@@ -235,17 +231,16 @@ MVMEBug_getchar_status
 {	register unsigned long	d0 asm("d0");
 
 	asm volatile (
-		"	move.l	#0,-(%%sp)
-			trap	#15
-			dc.w	0x0001
-			beq.s	1f
-			move.l	#1,(%%sp)
-		1:
-			move.l	(%%sp)+,%%d0
-		"
+		"	move.l	#0,-(%%sp)		\n\
+			trap	#15				\n\
+			dc.w	0x0001			\n\
+			beq.s	1f				\n\
+			move.l	#1,(%%sp)		\n\
+		1:							\n\
+			move.l	(%%sp)+,%%d0	\n\
+		"		
 		: "=r" (d0)
 		: /* no inputs */
-		: "d0"
 	);
 
 	return d0;
@@ -264,13 +259,12 @@ MVMEBug_rtc_read
 {	register void *			d0 asm("d0") = (void *) buf;
 
 	asm volatile (
-		"	move.l	%%d0,-(%%sp)
-			trap	#15
-			dc.w	0x0053
+		"	move.l	%%d0,-(%%sp)	\n\
+			trap	#15				\n\
+			dc.w	0x0053			\n\
 		"
 		: /* no outputs */
 		: "r" (d0)
-		: "d0"
 	);
 }
 
@@ -287,13 +281,13 @@ MVMEBug_disk_read
 {	register void	*d0 asm("d0") = (void *) cmnd;
 
 	asm volatile (
-		"	move.l	%%d0,-(%%sp)
-			trap	#15
-			dc.w	0x0010
+		"	move.l	%%d0,-(%%sp)	\n\
+			trap	#15				\n\
+			dc.w	0x0010			\n\
 		"
 		: /* no outputs */
 		: "r" (d0)
-		: "d0", "memory"
+		: "memory"
 	);
 }
 
@@ -310,13 +304,13 @@ MVMEBug_net_read
 {	register void	*d0 asm("d0") = (void *) niop;
 
 	asm volatile (
-		"	move.l	%%d0,-(%%sp)
-			trap	#15
-			dc.w	0x0018
+		"	move.l	%%d0,-(%%sp)	\n\
+			trap	#15				\n\
+			dc.w	0x0018			\n\
 		"
 		: /* no outputs */
 		: "r" (d0)
-		: "d0", "memory"
+		: "memory"
 	);
 }
 
@@ -332,8 +326,8 @@ MVMEBug_enter
 )
 {
 	asm volatile (
-		"	trap	#15
-			dc.w	0x0063
+		"	trap	#15			\n\
+			dc.w	0x0063		\n\
 		"
 		: /* No outputs */
 		: /* No inputs  */
@@ -355,14 +349,13 @@ MVMEBug_brdid
 {	register void *			d0 asm("d0");
 
 	asm volatile (
-		"	subq.l	#4,%%sp
-			trap	#15
-			dc.w	0x0070
-			move.l	(%%sp)+,%%d0
+		"	subq.l	#4,%%sp			\n\
+			trap	#15				\n\
+			dc.w	0x0070			\n\
+			move.l	(%%sp)+,%%d0	\n\
 		"
 		: "=r" (d0)
 		: /* no inputs */
-		: "d0"
 	);
 
 	return d0;
